==> opensaml-xmlsec-impl-3.3.0-sources.jar: org/opensaml/xmlsec/signature/impl/KeyInfoReferenceBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xmlsec.signature.impl;

import org.opensaml.core.xml.AbstractXMLObjectBuilder;
import org.opensaml.xmlsec.signature.KeyInfoReference;
import org.opensaml.xmlsec.signature.XMLSignatureBuilder;
import org.opensaml.xmlsec.signature.support.SignatureConstants;

/**
 * Builder of {@link KeyInfoReference}.
 */
public class KeyInfoReferenceBuilder extends AbstractXMLObjectBuilder<KeyInfoReference>
    implements XMLSignatureBuilder<KeyInfoReference> {

    /**
     * Constructor.
     */
    public KeyInfoReferenceBuilder() {
    }

    /** {@inheritDoc} */
    public KeyInfoReference buildObject(String namespaceURI, String localName, String namespacePrefix) {
        return new KeyInfoReferenceImpl(namespaceURI, localName, namespacePrefix);
    }

    /** {@inheritDoc} */
    public KeyInfoReference buildObject() {
        return buildObject(SignatureConstants.XMLSIG11_NS, KeyInfoReference.DEFAULT_ELEMENT_LOCAL_NAME,
                SignatureConstants.XMLSIG11_PREFIX);
    }

}

==> opensaml-xmlsec-impl-4.3.1-sources.jar: org/opensaml/xmlsec/signature/impl/KeyInfoReferenceBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xmlsec.signature.impl;

import org.opensaml.core.xml.AbstractXMLObjectBuilder;
import org.opensaml.xmlsec.signature.KeyInfoReference;
import org.opensaml.xmlsec.signature.XMLSignatureBuilder;
import org.opensaml.xmlsec.signature.support.SignatureConstants;

/**
 * Builder of {@link KeyInfoReference}.
 */
public class KeyInfoReferenceBuilder extends AbstractXMLObjectBuilder<KeyInfoReference>
    implements XMLSignatureBuilder<KeyInfoReference> {

    /**
     * Constructor.
     */
    public KeyInfoReferenceBuilder() {
    }

    /** {@inheritDoc} */
    public KeyInfoReference buildObject(final String namespaceURI, final String localName,
            final String namespacePrefix) {
        return new KeyInfoReferenceImpl(namespaceURI, localName, namespacePrefix);
    }

    /** {@inheritDoc} */
    public KeyInfoReference buildObject() {
        return buildObject(SignatureConstants.XMLSIG11_NS, KeyInfoReference.DEFAULT_ELEMENT_LOCAL_NAME,
                SignatureConstants.XMLSIG11_PREFIX);
    }

}
